@@ -37,7 +37,7 @@ class TQFrame;
 */
 class KatapultConfigDlg : public KDialogBase
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 	KatapultConfigDlg(KatapultSettings *settings);
