@@ -24,7 +24,7 @@
 
 #include <tqptrlist.h>
 
-#include "cachedcatalog.h"
+#include <cachedcatalog.h>
 
 class TQWidget;
 class TQString;
@@ -37,7 +37,7 @@ class BookmarkCatalogSettings;
 */
 class BookmarkCatalog : public CachedCatalog
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	BookmarkCatalog(TQObject *, const char *, const TQStringList&);
