@@ -22,14 +22,14 @@
 
 #include <tqpixmap.h>
 
-#include "katapultitem.h"
+#include <katapultitem.h>
 
 /**
 @author Joe Ferris
 */
 class MozillaBookmark : public KatapultItem
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	MozillaBookmark(TQString, TQString, TQPixmap);
