@@ -25,7 +25,7 @@
 #include <tdelocale.h>
 
 #include "program.h"
-#include "katapultitem.h"
+#include <katapultitem.h>
 #include "actionrunprogram.h"
 
 ActionRunProgram::ActionRunProgram()
