@@ -34,7 +34,7 @@ class SpellCatalog;
 */
 class Spelling : public KatapultItem
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		Spelling(SpellCatalog*, const TQString&);
