@@ -27,7 +27,7 @@
  */
 class PureDisplay : public ImageDisplay
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		PureDisplay(TQWidget *, const char *, const TQStringList&);
